@@ -1,9 +1,9 @@
 -- Example.hs  --  Examples from HUnit user's guide
 --
 -- For more examples, check out the tests directory.  It contains unit tests
--- for HUnit. 
+-- for HUnit.
 
-module Main where
+module Example where
 
 import Test.HUnit
 
@@ -36,5 +36,5 @@ tests' = test [ "test1" ~: "(foo 3)" ~: (1,2) ~=? (foo 3),
                               partB y @? "(partB " ++ show y ++ ") failed" ]
 
 main :: IO Counts
-main = do runTestTT tests
+main = do _ <- runTestTT tests
           runTestTT tests'
