@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 module HUnitTestExtended (
     extendedTests
     ) where
@@ -5,6 +6,11 @@ module HUnitTestExtended (
 import Test.HUnit
 import HUnitTestBase
 
+#if MIN_VERSION_base(4,9,0)
+errorCall :: a
+errorCall = error "error"
+#endif
+
 extendedTests :: Test
 extendedTests = test [
 
@@ -16,8 +22,13 @@ extendedTests = test [
     "list ref out of bounds" ~:
         expectUnspecifiedError (TestCase ([1 .. 4 :: Integer] !! 10 `seq` return ())),
 
+#if MIN_VERSION_base(4,9,0)
     "error" ~:
+        expectError "error\nCallStack (from HasCallStack):\n  error, called at tests/HUnitTestExtended.hs:11:13 in main:HUnitTestExtended" (TestCase errorCall),
+#else
+     "error" ~:
         expectError "error" (TestCase (error "error")),
+#endif
 
     "tail []" ~:
         expectUnspecifiedError (TestCase (tail [] `seq` return ()))
